@@ -1,8 +1,8 @@
 package Cassandra::Client;
 our $AUTHORITY = 'cpan:TVDW';
-$Cassandra::Client::VERSION = '0.14_001'; # TRIAL
+$Cassandra::Client::VERSION = '0.14_002'; # TRIAL
 
-$Cassandra::Client::VERSION = '0.14001';# ABSTRACT: Perl library for accessing Cassandra using its binary network protocol
+$Cassandra::Client::VERSION = '0.14002';# ABSTRACT: Perl library for accessing Cassandra using its binary network protocol
 
 use 5.010;
 use strict;
@@ -195,7 +195,7 @@ sub _prepare {
         return _cb($callback);
     }
 
-    $self->_command("prepare", [ $callback, $query ]);
+    $self->_command("prepare", $callback, [ $query ]);
     return;
 }
 
@@ -532,7 +532,7 @@ Cassandra::Client - Perl library for accessing Cassandra using its binary networ
 
 =head1 VERSION
 
-version 0.14_001
+version 0.14_002
 
 =head1 DESCRIPTION
 
@@ -614,6 +614,10 @@ Maximum time to wait for a query, in seconds. Defaults to C<11>.
 
 Whether to connect to the full cluster in C<connect()>, or delay that until queries come in.
 
+=item protocol_version
+
+Cassandra protocol version to use. Currently defaults to C<4>, can also be set to C<3> for compatibility with older versions of Cassandra.
+
 =back
 
 =item $client->batch($queries[, $attributes])
