@@ -1,8 +1,8 @@
 package Cassandra::Client::Config;
 our $AUTHORITY = 'cpan:TVDW';
-$Cassandra::Client::Config::VERSION = '0.14_001'; # TRIAL
+$Cassandra::Client::Config::VERSION = '0.14_002'; # TRIAL
 
-$Cassandra::Client::Config::VERSION = '0.14001';use 5.010;
+$Cassandra::Client::Config::VERSION = '0.14002';use 5.010;
 use strict;
 use warnings;
 
@@ -31,6 +31,7 @@ sub new {
         command_queue           => undef,
         retry_policy            => undef,
         load_balancing_policy   => undef,
+        protocol_version        => 4,
     }, $class;
 
     if (my $cp= $config->{contact_points}) {
@@ -89,6 +90,14 @@ sub new {
     $self->{username}= $config->{username};
     $self->{password}= $config->{password};
 
+    if (exists $config->{protocol_version}) {
+        if ($config->{protocol_version} == 3 || $config->{protocol_version} == 4) {
+            $self->{protocol_version}= 0+ $config->{protocol_version};
+        } else {
+            die "Invalid protocol_version: must be one of [3, 4]";
+        }
+    }
+
     return $self;
 }
 
@@ -104,7 +113,7 @@ Cassandra::Client::Config
 
 =head1 VERSION
 
-version 0.14_001
+version 0.14_002
 
 =head1 AUTHOR
 
