@@ -1,8 +1,8 @@
 package Cassandra::Client::Connection;
 our $AUTHORITY = 'cpan:TVDW';
-$Cassandra::Client::Connection::VERSION = '0.14_001'; # TRIAL
+$Cassandra::Client::Connection::VERSION = '0.14_002'; # TRIAL
 
-$Cassandra::Client::Connection::VERSION = '0.14001';use 5.010;
+$Cassandra::Client::Connection::VERSION = '0.14002';use 5.010;
 use strict;
 use warnings;
 use vars qw/$BUFFER/;
@@ -32,6 +32,7 @@ use Cassandra::Client::Protocol qw/
     unpack_metadata
     unpack_shortbytes
     unpack_string
+    unpack_stringlist
     unpack_stringmultimap
 /;
 use Cassandra::Client::Error::Base;
@@ -77,6 +78,7 @@ sub new {
         tls_want_write  => undef,
 
         healthcheck     => undef,
+        protocol_version => $args{options}{protocol_version},
     }, $class;
     weaken($self->{async_io});
     weaken($self->{client});
@@ -384,11 +386,11 @@ sub prepare {
 
             my ($encoder, $decoder);
             eval {
-                ($encoder)= unpack_metadata($body);
+                ($encoder)= unpack_metadata($self->{protocol_version}, 0, $body);
                 1;
             } or return $next->("Unable to unpack query metadata: $@");
             eval {
-                ($decoder)= unpack_metadata($body);
+                ($decoder)= unpack_metadata($self->{protocol_version}, 1, $body);
                 1;
             } or return $next->("Unable to unpack query result metadata: $@");
 
@@ -410,7 +412,12 @@ sub decode_result {
     my $result_type= unpack('l>', substr($_[3], 0, 4, ''));
     if ($result_type == RESULT_ROWS) { # Rows
         my ($paging_state, $decoder);
-        eval { ($decoder, $paging_state)= unpack_metadata($_[3]); 1 } or return $callback->("Unable to unpack query metadata: $@");
+        eval {
+            ($decoder, $paging_state)= unpack_metadata($self->{protocol_version}, 1, $_[3]);
+            1;
+        } or do {
+            return $callback->("Unable to unpack query metadata: $@");
+        };
         $decoder= $prepared->{decoder} || $decoder;
 
         $callback->(undef,
@@ -445,7 +452,7 @@ sub wait_for_schema_agreement {
 
     my $waited= 0;
     my $wait_delay= 0.5;
-    my $max_wait= 5;
+    my $max_wait= 20;
 
     my $done;
     whilst(
@@ -453,17 +460,7 @@ sub wait_for_schema_agreement {
         sub {
             my ($whilst_next)= @_;
 
-            series([
-                sub {
-                    my ($next)= @_;
-                    $self->{async_io}->timer($next, $wait_delay);
-                },
-                sub {
-                    my ($next)= @_;
-                    $waited += $wait_delay;
-                    $self->get_network_status($next);
-                },
-            ], sub {
+            $self->get_network_status(sub {
                 my ($error, $network_status)= @_;
                 return $whilst_next->($error) if $error;
 
@@ -473,10 +470,13 @@ sub wait_for_schema_agreement {
                     if ($waited >= $max_wait) {
                         return $whilst_next->("wait_for_schema_agreement timed out after $waited seconds");
                     }
+
+                    $waited += $wait_delay;
+                    return $self->{async_io}->timer($whilst_next, $wait_delay);
                 } else {
                     $done= 1;
+                    return $whilst_next->();
                 }
-                return $whilst_next->();
             });
         },
         $callback,
@@ -754,7 +754,7 @@ sub request {
             $compress_func->($_[3]);
         }
 
-        my $data= pack('CCsCN/a', 3, $flags, $stream_id, $opcode, $_[3]);
+        my $data= pack('CCsCN/a', $self->{protocol_version}, $flags, $stream_id, $opcode, $_[3]);
 
         if (defined $self->{pending_write}) {
             $self->{pending_write} .= $data;
@@ -907,10 +907,21 @@ READ_NEXT:
         my $body= substr($BUFFER, 0, $bodylen, '');
         $bufsize -= 9 + $bodylen;
 
-        # Decompress if needed
         if (($flags & 1) && $body) {
+            # Decompress if needed
             $self->{decompress_func}->($body);
         }
+        if ($flags & 4) {
+            # FIXME: If we reach this (we shouldn't!), we're corrupting the user's data.
+            warn 'BUG: unexpectedly received custom QueryHandler payload';
+        }
+        if ($flags & 8) {
+            # Warnings were sent from the server. Relay them.
+            my $warnings= unpack_stringlist($body);
+            for my $warning (@$warnings) {
+                warn $warning;
+            }
+        }
 
         if ($stream_id != -1) {
             my $stream_cb= delete $self->{pending_streams}{$stream_id};
@@ -1145,7 +1156,7 @@ Cassandra::Client::Connection
 
 =head1 VERSION
 
-version 0.14_001
+version 0.14_002
 
 =head1 AUTHOR
 
