@@ -1,8 +1,8 @@
 package Cassandra::Client::Protocol;
 our $AUTHORITY = 'cpan:TVDW';
-$Cassandra::Client::Protocol::VERSION = '0.14_001'; # TRIAL
+$Cassandra::Client::Protocol::VERSION = '0.14_002'; # TRIAL
 
-$Cassandra::Client::Protocol::VERSION = '0.14001';use 5.010;
+$Cassandra::Client::Protocol::VERSION = '0.14002';use 5.010;
 use strict;
 use warnings;
 
@@ -335,7 +335,8 @@ sub unpack_stringmultimap {
 
 # Metadata
 sub pack_metadata {
-    my ($metadata)= @_;
+    my ($protoversion, $is_result, $metadata)= @_;
+    die "pack_metadata can only encode v4 results" unless $protoversion == 4 and $is_result;
     my $columns= $metadata->{columns};
     my $paging_state= $metadata->{paging_state};
 
@@ -444,7 +445,7 @@ Cassandra::Client::Protocol
 
 =head1 VERSION
 
-version 0.14_001
+version 0.14_002
 
 =head1 AUTHOR
 
